\name{fabia}
\alias{fabia}
\title{Factor Analysis for Bicluster Acquisition: Laplace Prior (FABIA)}
\description{

  \code{fabia}: C implementation of  \code{fabia}.
}
\usage{

fabia(X,cyc,alpha,spl,spz,p,random=NULL,scale=0.0,norm=1,center=2,lap=1.0)

}
\arguments{
  \item{X}{the data matrix.}
  \item{cyc}{number of cycles to run.}
  \item{alpha}{sparseness loadings (0.1 - 1.0).}
  \item{spl}{sparseness prior loadings (0.5 - 4.0).}
  \item{spz}{sparseness factors (0.5 - 4.0).}
  \item{p}{number of hidden factors = number of biclusters.}
  \item{random}{random initialization of loadings in
    [-random,random] (if not given: half of the square root of variance of
    component).}
  \item{scale}{loading vectors are scaled in each iteration to the given
    variance. zero (default) indicates that non scaling.}
  \item{norm}{data normalization: default = 1 (yes), 0 (no).}
  \item{center}{data centering: 1 (mean), 2
    (median), > 2 (mode), 0 (no); default 2.}
  \item{lap}{minimal value of the variational parameter, default = 1.0} 
}
\details{

  Biclusters are found by sparse factor analysis where \emph{both} the factors
  and the loadings are sparse.

  Essentially the model is the sum of
  outer products of vectors:
   \deqn{X \ = \ \sum_{i=1}^{p} \lambda_i \
                   z_i^T \ + \ U}
  where the number of summands  $p$
  is the number of biclusters.
  The matrix factorization is
  \deqn{X \ = \ L \ Z \ + \ U}.
  

  If the nonzero components of
  the sparse vectors are grouped together then the outer product results in
  a matrix with a nonzero block and zeros elsewhere.


  The model selection is performed by a variational approach according
  to Girolami 2001 and Palmer et al. 2006.

  We included a prior on the parameters and minimize
  a lower bound on the posterior
  of the parameters given the data.
  The update of the loadings includes an additive term which pushes the
  loadings toward zero (Gaussian prior leads to an multiplicative factor).

  The code is implemented in C using the Rcpp package.

}
\value{
  \item{LZ}{Estimated Noise Free Data:
    \eqn{L \ Z}}
  \item{L}{Loadings:  \eqn{L}}
  \item{Z}{Factors:  \eqn{Z}}
  \item{Psi}{Noise variance: \eqn{\sigma}}
  \item{lapla}{Variational parameter}
    }
\seealso{
\code{\link{fabi}},
\code{\link{fabiap}},
\code{\link{fabias}},
\code{\link{fabiasp}},
\code{\link{mfsc}},
\code{\link{nmfdiv}},
\code{\link{nmfeu}},
\code{\link{nmfsc}},
\code{\link{nprojfunc}},
\code{\link{projfunc}},
\code{\link{estimateMode}},
\code{\link{make_fabi_data}},
\code{\link{make_fabi_data_blocks}},
\code{\link{make_fabi_data_pos}},
\code{\link{make_fabi_data_blocks_pos}},
\code{\link{extract_plot}},
\code{\link{extract_bic}},
\code{\link{myImagePlot}},
\code{\link{PlotBicluster}},
\code{\link{Breast_A}},
\code{\link{DLBCL_B}},
\code{\link{Multi_A}},
\code{\link{fabiaDemo}},
\code{\link{fabiaVersion}}
}
\author{Sepp Hochreiter}
\examples{

#---------------
# TEST
#---------------

dat <- make_fabi_data_blocks(n = 100,l= 50,p = 3,f1 = 5,f2 = 5,
  of1 = 5,of2 = 10,sd_noise = 3.0,sd_z_noise = 0.2,mean_z = 2.0,
  sd_z = 1.0,sd_l_noise = 0.2,mean_l = 3.0,sd_l = 1.0)

X <- dat[[1]]
Y <- dat[[2]]


resEx <- fabia(X,50,0.3,1.0,1.0,3)


\dontrun{
#---------------
# DEMO1
#---------------

dat <- make_fabi_data_blocks(n = 1000,l= 100,p = 10,f1 = 5,f2 = 5,
  of1 = 5,of2 = 10,sd_noise = 3.0,sd_z_noise = 0.2,mean_z = 2.0,
  sd_z = 1.0,sd_l_noise = 0.2,mean_l = 3.0,sd_l = 1.0)

X <- dat[[1]]
Y <- dat[[2]]


resToy <- fabia(X,400,0.1,1.0,1.0,13)

rToy <- extract_plot(X,resToy$L,resToy$Z,ti="FABIA",Y=Y)

#---------------
# DEMO2
#---------------

data(Breast_A)

X <- as.matrix(XBreast)
resBreast <- fabia(X,400,0.1,1.0,1.0,5)

rBreast <- extract_plot(X,resBreast$L,resBreast$Z,"FABIA Breast cancer(Veer)")

#sorting of predefined labels
CBreast%*%rBreast$pmZ

#---------------
# DEMO3
#---------------

data(Multi_A)

X <- as.matrix(XMulti)

resMulti <- fabia(X,400,0.1,1.0,1.0,5)

rMulti <- extract_plot(X,resMulti$L,resMulti$Z,ti="FABIA Multiple tissues(Su)")

#sorting of predefined labels
CMulti%*%rMulti$pmZ

#---------------
# DEMO4
#---------------

data(DLBCL_B)

X <- as.matrix(XDLBCL)


resDLBCL <- fabia(X,400,0.1,1.0,1.0,5)

rDLBCL <- extract_plot(X,resDLBCL$L,resDLBCL$Z,ti="FABIA Lymphoma(Rosenwald)")

#sorting of predefined labels
CDLBCL%*%rDLBCL$pmZ
}
}
\references{
  Mark Girolami,
  \sQuote{A Variational Method for Learning Sparse and
  Overcomplete Representations},
  Neural Computation 13(11): 2517-2532, 2001.

  J. Palmer, D. Wipf, K. Kreutz-Delgado, B. Rao,
  \sQuote{Variational EM algorithms for
     non-Gaussian latent variable models},
     Advances in Neural Information Processing
     Systems 18, pp. 1059-1066, 2006.

}
\keyword{methods}
\keyword{multivariate}
\keyword{cluster}
\concept{biclustering}
\concept{factor analysis}
\concept{sparse coding}
\concept{Laplace distribution}
\concept{EM algorithm}
\concept{non-negative matrix factorization}
\concept{multivariate analysis}
\concept{latent variables}


