\name{fabiap}
\alias{fabiap}
\title{Factor Analysis for Bicluster Acquisition: Post-Projection (FABIAP)}
\description{

  \code{fabiap}: C implementation of  \code{fabiap}.
}
\usage{

fabiap(X,cyc,alpha,spl,spz,p,sL,sZ,random=NULL,scale=0.0,norm=1,center=2,lap=1.0)

}
\arguments{
  \item{X}{the data matrix.}
  \item{cyc}{number of cycles to run.}
  \item{alpha}{sparseness loadings (0.1 - 1.0).}
  \item{spl}{sparseness prior loadings (0.5 - 4.0).}
  \item{spz}{sparseness factors (0.5 - 4.0).}
  \item{p}{number of hidden factors = number of biclusters.}
  \item{sL}{final sparseness loadings.}
  \item{sZ}{final sparseness factors.}
  \item{random}{random initialization of loadings in
    [-random,random] (if not given: half of the square root of variance of
    component).}
  \item{scale}{loading vectors are scaled in each iteration to the given
    variance. zero (default) indicates that non scaling.}
  \item{norm}{data normalization: default = 1 (yes), 0 (no).}
  \item{center}{data centering: 1 (mean), 2
    (median), > 2 (mode), 0 (no); default 2.}
  \item{lap}{minimal value of the variational parameter, default = 1.} 
}
\details{

  Biclusters are found by sparse factor analysis where \emph{both} the factors
  and the loadings are sparse. Post-processing by projecting the final
  results to a given sparseness criterion.

  Essentially the model is the sum of
  outer products of vectors:
   \deqn{X \ = \ \sum_{i=1}^{p} \lambda_i \
                   z_i^T \ + \ U}
  where the number of summands  $p$
  is the number of biclusters.
  The matrix factorization is
  \deqn{X \ = \ L \ Z \ + \ U}.
  


  If the nonzero components of
  the sparse vectors are grouped together then the outer product results in
  a matrix with a nonzero block and zeros elsewhere.


 	   The model selection is performed by a variational approach according
  to Girolami 2001 and Palmer et al. 2006.

  We included a prior on the parameters and minimize
  a lower bound on the posterior
  of the parameters given the data.
  The update of the loadings includes an additive term which pushes the
  loadings toward zero (Gaussian prior leads to an multiplicative factor).

  \bold{Post-processing:}
  The final results of the loadings and the factors are projected to
  a sparse vector according to Hoyer, 2004: given an
  \eqn{l_1}-norm and an \eqn{l_2}-norm minimize the Euclidean distance
  to the original vector (currently the \eqn{l_2}-norm is fixed to 1).
  The projection is a convex quadratic problem which is solved
  iteratively where at each iteration at least one component is set to
  zero. Instead of the  \eqn{l_1}-norm a sparseness measurement is used
  which relates the \eqn{l_1}-norm to the \eqn{l_2}-norm:


  The code is implemented in C using the Rcpp package. The projection is
  implemented in \R.

}
\value{
  \item{Lz}{Estimated Noise Free Data:
    \eqn{L \ Z}}
  \item{L}{Loadings:  \eqn{L}}
  \item{z}{Factors:  \eqn{Z}}
  \item{Psi}{Noise variance: \eqn{\sigma}}
  \item{lapla}{Variational parameter}
    }
\seealso{
\code{\link{fabi}},
\code{\link{fabia}},
\code{\link{fabias}},
\code{\link{fabiasp}},
\code{\link{mfsc}},
\code{\link{nmfdiv}},
\code{\link{nmfeu}},
\code{\link{nmfsc}},
\code{\link{nprojfunc}},
\code{\link{projfunc}},
\code{\link{estimateMode}},
\code{\link{make_fabi_data}},
\code{\link{make_fabi_data_blocks}},
\code{\link{make_fabi_data_pos}},
\code{\link{make_fabi_data_blocks_pos}},
\code{\link{extract_plot}},
\code{\link{extract_bic}},
\code{\link{myImagePlot}},
\code{\link{PlotBicluster}},
\code{\link{Breast_A}},
\code{\link{DLBCL_B}},
\code{\link{Multi_A}},
\code{\link{fabiaDemo}},
\code{\link{fabiaVersion}}
}
\author{Sepp Hochreiter}
\examples{

#---------------
# TEST
#---------------

dat <- make_fabi_data_blocks(n = 100,l= 50,p = 3,f1 = 5,f2 = 5,
  of1 = 5,of2 = 10,sd_noise = 3.0,sd_z_noise = 0.2,mean_z = 2.0,
  sd_z = 1.0,sd_l_noise = 0.2,mean_l = 3.0,sd_l = 1.0)

X <- dat[[1]]
Y <- dat[[2]]

resEx <- fabiap(X,50,0.3,1.0,1.0,3,0.7,0.7)


\dontrun{
#---------------
# DEMO1
#---------------

dat <- make_fabi_data_blocks(n = 1000,l= 100,p = 10,f1 = 5,f2 = 5,
  of1 = 5,of2 = 10,sd_noise = 3.0,sd_z_noise = 0.2,mean_z = 2.0,
  sd_z = 1.0,sd_l_noise = 0.2,mean_l = 3.0,sd_l = 1.0)

X <- dat[[1]]
Y <- dat[[2]]


resToy <- fabiap(X,200,0.4,1.0,1.0,13,0.7,0.7)

rToy <- extract_plot(X,resToy$L,resToy$Z,ti="FABIAP",Y=Y)

#---------------
# DEMO2
#---------------

data(Breast_A)

X <- as.matrix(XBreast)

resBreast <- fabiap(X,200,0.1,1.0,1.0,5,0.5,0.3)

rBreast <- extract_plot(X,resBreast$L,resBreast$Z,ti="FABIAP Breast cancer(Veer)")

#sorting of predefined labels
CBreast%*%rBreast$pmZ

#---------------
# DEMO3
#---------------


data(Multi_A)

X <- as.matrix(XMulti)

resMulti <- fabiap(X,200,0.1,1.0,1.0,5,0.5,0.3)

rMulti <- extract_plot(X,resMulti$L,resMulti$Z,ti="FABIAP Multiple tissues(Su)")

#sorting of predefined labels
CMulti%*%rMulti$pmZ

#---------------
# DEMO4
#---------------


data(DLBCL_B)

X <- as.matrix(XDLBCL)

resDLBCL <- fabiap(X,200,0.1,1.0,1.0,5,0.5,0.3)

rDLBCL <- extract_plot(X,resDLBCL$L,resDLBCL$Z,ti="FABIAP Lymphoma(Rosenwald)")

#sorting of predefined labels
CDLBCL%*%rDLBCL$pmZ

}
}
\references{
  Mark Girolami,
  \sQuote{A Variational Method for Learning Sparse and
  Overcomplete Representations},
  Neural Computation 13(11): 2517-2532, 2001.
  
  J. Palmer, D. Wipf, K. Kreutz-Delgado, B. Rao,
  \sQuote{Variational EM algorithms for
     non-Gaussian latent variable models},
     Advances in Neural Information Processing
     Systems 18, pp. 1059-1066, 2006.

  Patrik O. Hoyer,
  \sQuote{Non-negative Matrix Factorization with Sparseness Constraints},
  Journal of Machine Learning Research 5:1457-1469, 2004.
}
\keyword{methods}
\keyword{multivariate}
\keyword{cluster}
\concept{biclustering}
\concept{factor analysis}
\concept{sparse coding}
\concept{Laplace distribution}
\concept{EM algorithm}
\concept{non-negative matrix factorization}
\concept{multivariate analysis}
\concept{latent variables}
